@@ -105,6 +105,11 @@ _lib.td_fill_centroids.argtypes = [
     ndpointer(ctypes.c_double, flags="C_CONTIGUOUS"),
 ]
 
+_lib.td_scale_weight.argtypes = [
+    ctypes.POINTER(_TDigest),
+    ctypes.c_double,
+]
+
 
 class TDigest:
 
@@ -129,6 +134,7 @@ class TDigest:
             elif raise_if_nans:
                 raise ValueError("Value is invalid.")
         elif isinstance(x, np.ndarray):
+            x = x.astype('float')
             # TODO: make this robust to nans and infinities
             if w is None:
                 w = np.ones_like(x)
@@ -269,6 +275,9 @@ class TDigest:
                 raise TypeError(f'Both first and second arguments have to be instances of TDigest.')
             return first + second
 
+    def scale_weight(self, factor):
+        _lib.td_scale_weight(self._tdigest, float(factor))
+
     @property
     def weight(self):
         return _lib.td_total_weight(self._tdigest)
